//#define XERR
#include "tomo.ih"

double Tomo::vDose(uint16_t idx) const
{
    return d_dose[idx].value();
}
